@@ -705,17 +705,25 @@ frdp_key_pressed (GtkWidget   *widget,
   VinagreRdpTab        *rdp_tab = (VinagreRdpTab *) user_data;
   VinagreRdpTabPrivate *priv = rdp_tab->priv;
   frdpEventKey         *frdp_event;
+#if HAVE_FREERDP_1_1
+  UINT16                scancode;
+#endif
 
   frdp_event = g_new0 (frdpEventKey, 1);
   frdp_event->type = FRDP_EVENT_TYPE_KEY;
   frdp_event->flags = event->type == GDK_KEY_PRESS ? KBD_FLAGS_DOWN : KBD_FLAGS_RELEASE;
 
 #if HAVE_FREERDP_1_1
-  frdp_event->code = freerdp_keyboard_get_rdp_scancode_from_x11_keycode (event->hardware_keycode);
+  scancode = freerdp_keyboard_get_rdp_scancode_from_x11_keycode (event->hardware_keycode);
+  frdp_event->code = RDP_SCANCODE_CODE(scancode);
+  frdp_event->extended = RDP_SCANCODE_EXTENDED(scancode);
 #else
   frdp_event->code = freerdp_kbd_get_scancode_by_keycode (event->hardware_keycode, &frdp_event->extended);
 #endif
 
+  if (frdp_event->extended)
+    frdp_event->flags |= KBD_FLAGS_EXTENDED;
+
   g_queue_push_tail (priv->events, frdp_event);
 
   return TRUE;
@@ -1187,8 +1195,8 @@ open_freerdp (VinagreRdpTab *rdp_tab)
   VinagreTab           *tab = VINAGRE_TAB (rdp_tab);
   GtkWindow            *window = GTK_WINDOW (vinagre_tab_get_window (tab));
   gboolean              success = TRUE;
-  gboolean              authentication_error = FALSE;
   gboolean              cancelled = FALSE;
+  guint                 authentication_errors = 0;
 
   priv->events = g_queue_new ();
 
@@ -1197,14 +1205,12 @@ open_freerdp (VinagreRdpTab *rdp_tab)
 
   do
     {
-      authentication_error = FALSE;
-
       /* Run FreeRDP session */
       success = freerdp_connect (priv->freerdp_session);
       if (!success)
         {
-          authentication_error = freerdp_get_last_error (priv->freerdp_session->context) == 0x20009 ||
-                                 freerdp_get_last_error (priv->freerdp_session->context) == 0x2000c;
+          authentication_errors += freerdp_get_last_error (priv->freerdp_session->context) == 0x20009 ||
+                                   freerdp_get_last_error (priv->freerdp_session->context) == 0x2000c;
 
           cancelled = freerdp_get_last_error (priv->freerdp_session->context) == 0x2000b;
 
@@ -1212,7 +1218,7 @@ open_freerdp (VinagreRdpTab *rdp_tab)
           init_freerdp (rdp_tab);
         }
     }
-  while (!success && authentication_error);
+  while (!success && authentication_errors < 3);
 
   if (!success)
     {
